# Packages names
%global vdsm_name vdsm

# Required users and groups
%global vdsm_user vdsm
%global vdsm_group kvm
%global qemu_user qemu
%global qemu_group qemu
%global snlk_group sanlock
%global snlk_user sanlock
%global cdrom_group cdrom
# Not configurable because owned by ovirt-vmconsole package
%global vmcon_user ovirt-vmconsole
%global vmcon_group ovirt-vmconsole

# Features
%global with_ovirt_imageio 1
%global with_ovirt_vmconsole 1
%global with_gluster_mgmt 1
%global with_hooks 1
%global with_vhostmd 1
%global with_python3 0
%global with_containers 0

%ifarch ppc64le
%global with_openvswitch 0
%else
%global with_openvswitch 1
%endif

%if 0%{?centos} || 0%{?fedora}
%global gluster_version 3.10
%else #rhel
%global gluster_version 3.8
%endif

# Default to skipping autoreconf.  Distros can change just this one line
# (or provide a command-line override) if they backport any patches that
# touch configure.ac or Makefile.am.
%{!?enable_autotools:%global enable_autotools 0}

# Required paths
%if 0%{?fedora}
%global _polkitdir %{_datadir}/polkit-1/rules.d
%else
%global _polkitdir %{_localstatedir}/lib/polkit-1/localauthority/10-vendor.d
%endif

# Disable debuginfo package, since vdsm is a meta-package
%global debug_package %{nil}

Name:           %{vdsm_name}
Version:        4.20.2
Release:        1%{?dist}%{?extra_release}
Summary:        Virtual Desktop Server Manager

Group:          Applications/System
License:        GPLv2+
Url:            http://www.ovirt.org/develop/developer-guide/vdsm/vdsm/
Source0:        http://resources.ovirt.org/pub/src/%{vdsm_name}/%{vdsm_name}-%{version}.tar.gz

%{!?_licensedir:%global license %%doc}

BuildRequires: openssl
BuildRequires: python
BuildRequires: python-cpopen
BuildRequires: python-six >= 1.9.0
BuildRequires: python-dateutil
BuildRequires: python2-devel
BuildRequires: PyYAML
BuildRequires: rpm-build
BuildRequires: systemd-units

# Autotools BuildRequires
%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
BuildRequires: libtool
%endif


# Numactl is not available on s390[x] and ARM
%ifnarch s390 s390x %{arm}
Requires: numactl
%endif

%ifarch x86_64
Requires: python-dmidecode
Requires: dmidecode
Requires: virt-v2v
%endif

Requires: chrony
Requires: dhclient
Requires: dbus-python
Requires: ethtool
Requires: which
Requires: sudo >= 1.7.3
Requires: logrotate
Requires: lshw
Requires: xz
Requires: iproute >= 3.10.0
Requires: PyYAML
Requires: python-dateutil
Requires: python-netaddr
Requires: python-inotify
Requires: python-cpopen >= 1.5
Requires: python-ioprocess >= 0.16.1-1
Requires: python-ipaddress
Requires: python-pthreading >= 0.1.3-3
Requires: python-six >= 1.9.0
Requires: python-requests
Requires: rpm-python
Requires: nfs-utils
Requires: libnl3
Requires: abrt-cli
Requires: abrt-addon-vmcore
Requires: abrt-addon-ccpp
Requires: abrt-addon-python
Requires: curl
Requires: %{name}-http = %{version}-%{release}
Requires: %{name}-jsonrpc = %{version}-%{release}
Requires: safelease >= 1.0-7
Requires: mom >= 0.5.8
Requires(pre): shadow-utils

Obsoletes: %{name}-infra < 4.19

%if 0%{?with_openvswitch}
Requires: openvswitch >= 2.0.0
%endif

%if 0%{?with_ovirt_imageio}
Requires: ovirt-imageio-common
Requires: ovirt-imageio-daemon
%endif

%if 0%{?with_ovirt_vmconsole}
Requires: ovirt-vmconsole >= 1.0.0-0
%endif

Requires: libvirt-client
Requires: libvirt-daemon-config-nwfilter
Requires: libvirt-lock-sanlock

# TODO: Depend on libvirt >= 3.2.0-4.el7 once available.
%if 0%{?rhel}
# For https://bugzilla.redhat.com/1317429
# TODO: Change to 3.2.0-9.el7 once it is available.
Requires: libvirt-daemon-kvm >= 2.0.0-10.el7_3.4
Requires: libvirt-python >= 2.0.0-2
%else # fedora
# TODO: Change to 3.3.0-1 once it is available.
Requires: libvirt-daemon-kvm >= 2.2.0-1
Requires: libvirt-python >= 2.2.0-1
%endif

# iscsi-intiator versions
Requires: iscsi-initiator-utils >= 6.2.0.873-21

Requires: sanlock >= 3.4.0-1, sanlock-python

# device-mapper-multipath

%if 0%{?rhel}
Requires: device-mapper-multipath >= 0.4.9-84.el7
%endif #rhel

%if 0%{?fedora}
Requires: device-mapper-multipath >= 0.4.9-80
%endif


Requires: policycoreutils-python
Requires: fence-agents-all
Requires: systemd >= 219-11
Requires: initscripts >= 9.49.31
Requires: cyrus-sasl-scram
Requires: lvm2 >= 2.02.145

%if 0%{?rhel}
Requires: e2fsprogs
Requires: kernel >= 3.10.0-327.18.1.el7
Requires: python >= 2.7.5-18.el7_1.1
Requires: selinux-policy-targeted >= 3.13.1-60.el7
%else
Requires: kernel >= 4.1.6
# Subprocess and thread bug was found on python 2.7.2
Requires: python >= 2.7.3
Requires: e2fsprogs >= 1.41.14
Requires: policycoreutils-python-utils
Requires: sed >= 4.2.1-10
Requires: ed
Requires: selinux-policy-targeted >= 3.13-1
# In order to avoid a policycoreutils bug (rhbz 889698) when selinux is
# disabled we now require the version 2.1.13-55 (or newer) of Fedora.
Requires: policycoreutils >= 2.1.13-55
%endif

%if 0%{?rhel}
Requires: qemu-kvm-rhev >= 10:2.6.0-28.el7_3.3
%else # fedora
Requires: qemu-kvm >= 2:2.7.0-7
%endif

# GlusterFS client-side RPMs needed for Gluster SD
%ifnarch ppc64le
Requires: glusterfs-cli >= %{gluster_version}
Requires: glusterfs-fuse >= %{gluster_version}
%endif

Requires: psmisc >= 22.6-15
Requires: bridge-utils
Requires: sos
Requires: tree
Requires: dosfstools
Requires: genisoimage
Requires: libselinux-python
Requires: %{name}-python = %{version}-%{release}
Requires: %{name}-hook-vmfex-dev = %{version}-%{release}
Requires: NetworkManager-config-server

%if 0%{?rhel}
Requires: python-decorator
%endif

%if 0%{?fedora}
Requires: python2-decorator
%endif

Requires(post): /usr/sbin/saslpasswd2

%if 0%{?fedora}
Requires(post): hostname
%else
Requires(post): /bin/hostname
%endif

Conflicts: vdsm-hook-sriov

%description
The VDSM service is required by a Virtualization Manager to manage the
Linux hosts. VDSM manages and monitors the host's storage, memory and
networks as well as virtual machine creation, other host administration
tasks, statistics gathering, and log collection.

%package http
Summary:        VDSM http API
BuildArch:      noarch
Provides: %{name}-xmlrpc = %{version}-%{release}
Requires: %{name}-python = %{version}-%{release}
Obsoletes: %{name}-xmlrpc < %{version}-%{release}

%description http
A http interface for interacting with vdsmd when using OVF store image
download or upload.

%package client
Summary:        VDSM client
BuildArch:      noarch
# A hack for unbreaking external packages that expect vdsm-cli.
Provides: %{name}-cli = %{version}-%{release}
Requires: %{name}-api = %{version}-%{release}
Requires: %{name}-yajsonrpc = %{version}-%{release}
Obsoletes: %{name}-cli < %{version}-%{release}

%description client
Access vdsm API from the command line.

%package api
Summary:        VDSM API
BuildArch:      noarch

%description api
Contains api schema files

%package jsonrpc
Summary:        VDSM API Server
BuildArch:      noarch
Requires:       %{name}-python = %{version}-%{release}
Requires:       %{name}-api = %{version}-%{release}
Requires:       %{name}-yajsonrpc = %{version}-%{release}
Obsoletes:      %{name}-api < 4.16

%description jsonrpc
A Json-based RPC interface that serves as the protocol for libvdsm.

%package yajsonrpc
Summary:        JSON RPC server and client implementation
BuildArch:      noarch
Requires:       python >= 2.6

%description yajsonrpc
A JSON RPC server and client implementation.

%package python
Summary:        VDSM python libraries
Requires:       %{name}-api = %{version}-%{release}
BuildArch:      noarch
Requires:       python-cpopen >= 1.5
Requires:       python-ioprocess >= 0.16.1-1

%description python
Shared libraries between the various VDSM packages.

%post python
# REQUIRED_FOR: Upgrade from 4.14 to 4.17
# HACK: Remove vdsm python lib __init__ file if installed on old location
# https://bugzilla.redhat.com/show_bug.cgi?id=1279167
if [ "$1" -ge 2 ]; then
    if [ -d "%{python2_sitearch}/%{vdsm_name}" ]; then
        logger -t '%{vdsm_name}' \
            'Disabling old vdsm package in %{python2_sitearch}/%{vdsm_name}.' \
            'Removing %{python2_sitearch}/%{vdsm_name}/init.py*'
        rm -f %{python2_sitearch}/%{vdsm_name}/__init__.py*
    fi
fi

%package tests
Summary:        VDSM Test Suite
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       dracut
Requires:       python-nose python-ipaddress

%description tests
A test suite for verifying the functionality of a running vdsm instance

%package hook-allocate_net
Summary:        random_network allocation hook for VDSM
BuildArch:      noarch
Requires:       %{name}

%description hook-allocate_net
VDSM hook used to allocate networks for vms in a random fashion

%package hook-checkimages
Summary:        Qcow2 disk image format check hook for VDSM
BuildArch:      noarch
Requires:       %{name}

%description hook-checkimages
VDSM hook used to perform consistency check on a qcow2 format disk image
using the QEMU disk image utility.

%package hook-checkips
Summary:        Check connectivity from the host to designated IPs
Requires:       %{name} = %{version}-%{release}

%description hook-checkips
VDSM hook used to check connectivity from the host network to designated IPs

%post hook-checkips
%systemd_post vdsm-checkips.service

%preun hook-checkips
%systemd_preun vdsm-checkips.service

%package hook-diskunmap
Summary:        Activate UNMAP for disk/lun devices
BuildArch:      noarch
Requires:       qemu-kvm >= 1.5

%description hook-diskunmap
VDSM hooks which allow to activate disk UNMAP.

%package hook-ethtool-options
Summary:        Allow setting custom ethtool options for vdsm controlled nics
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description hook-ethtool-options
VDSM hook used for applying custom network properties that define ethtool
options for vdsm network nics

%package hook-extra-ipv4-addrs
Summary:        Set extra ipv4 addresses for vdsm networks.

%description hook-extra-ipv4-addrs
This hook allows the user to set extra ipv4
addresses for vdsm networks.

%if 0%{?with_vhostmd}
%package hook-vhostmd
Summary:        VDSM hook set for interaction with vhostmd
BuildArch:      noarch
Requires:       vhostmd

%description hook-vhostmd
VDSM hook to use vhostmd per VM according to Virtualization Manager requests.
%endif

%package hook-faqemu
Summary:        Fake qemu process for VDSM quality assurance
BuildArch:      noarch
Requires:       %{name}

%description hook-faqemu
VDSM hook used for testing VDSM with multiple fake virtual machines without
running real guests.
To enable this hook on your host, set vars.fake_kvm_support=True in your
/etc/vdsm/vdsm.conf before adding the host to ovirt-Engine.

%package hook-localdisk
Summary:        Use a local image instead of a shared storage image
BuildArch:      noarch
Requires:       %{name} == %{version}

%description hook-localdisk
This hook add the ability to use fast local storage instead of shared
storage, while using shared storage for managing VM templates.
To enable this hook, the VM should have a custom property of 'localdisk=lvm'.
The system administrator will be responsible for creating the host "ovirt-local"
volume group and extending it with new devices if needed.
The VM must be pinned to host.

%package hook-macbind
Summary:        Bind a vNIC to a Bridge
BuildArch:      noarch
Requires:       %{name} >= 4.14

%description hook-macbind
VDSM hooks which allow to bind a vNIC to a Bridge, managed or not by engine.

%package hook-macspoof
Summary:        Disables MAC spoofing filtering
BuildArch:      noarch

%description hook-macspoof
VDSM hooks which allow to disable mac spoof filtering
either on all the of the VM's interfaces or on
specific vnics.

%package hook-noipspoof
Summary:        Enables strict anti-spoofing filtering
BuildArch:      noarch

%description hook-noipspoof
VDSM hook which allows to enable strict anti-spoofing filtering
on all of the the VM's interfaces.

%package hook-extnet
Summary:        Force a vNIC to connect to a specific libvirt network
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description hook-extnet
VDSM hook which allows to connect a vNIC to a libvirt network that is managed
outside of oVirt, such as an openvswitch network.

%package hook-fakevmstats
Summary:        Generate random VM statistics
BuildArch:      noarch
Requires:       %{name}

%description hook-fakevmstats
Hook intercepts VM's stats and randomizes various fields.
To enable this hook on your host, set vars.fake_vmstats_enable=true in your
/etc/vdsm/vdsm.conf.

%package hook-fakesriov
Summary:        Generate fake SR-IOV devices
Requires:       %{name}

%description hook-fakesriov
Hook intercepts reported host device by hostdevListByCaps and adds
1 fake sriov devices and 2 fake virtual function devices
To enable this hook on your host, set vars.fake_sriov_enable=true in your
/etc/vdsm/vdsm.conf.

%package hook-fileinject
Summary:        Allow uploading file to VMs disk
BuildArch:      noarch
Requires:       python-libguestfs

%description hook-fileinject
Hook is getting target file name and its content and
create that file in target machine.

%package hook-floppy
Summary:        Allow adding floppy to VM
BuildArch:      noarch

%description hook-floppy
Allow adding floppy to VM

%package hook-hostusb
Summary:        Allow attaching USB device from host
BuildArch:      noarch
Requires:       usbutils

%description hook-hostusb
Hook is getting vendor and product id of USB device
disconnect it from host and attach it to VM

%package hook-httpsisoboot
Summary:        Allow directly booting from an https available ISO
BuildArch:      noarch
%if 0%{?rhel}
Requires:       qemu-kvm-rhev >= 10:2.1.2-3
%endif

%description hook-httpsisoboot
Let the VM boot from an ISO image made available via an https URL without
the need to import the ISO into an ISO storage domain.
It doesn't support plain http.

%package hook-isolatedprivatevlan
Summary:        Isolated network environment for VMs
BuildArch:      noarch

%description hook-isolatedprivatevlan
limit VM traffic to a specific gateway by its mac address,
hook prevent VM from spoofing its mac or  ip address
by using <filterref filter='clean-traffic'/> libvirt filter
and by adding custom filter: isolatedprivatevlan-vdsm.xml

%package hook-nestedvt
Summary:        Nested Virtualization support for VDSM
BuildArch:      noarch

%description hook-nestedvt
If the nested virtualization is enabled in your kvm module
this hook will expose it to the guests.

%package hook-numa
Summary:        NUMA support for VDSM
BuildArch:      noarch

%description hook-numa
Hooks is getting number/rage of NUMA nodes and NUMA mode,
and update the VM xml.

%package hook-openstacknet
Summary:        OpenStack Network vNICs support for VDSM
BuildArch:      noarch

%description hook-openstacknet
Hook for OpenStack Network vNICs.

%package hook-pincpu
Summary:        Hook pin VM so specific CPUs
BuildArch:      noarch

%description hook-pincpu
pincpu is hook for VDSM.
pincpu enable to pin virtual machine to a specific CPUs.

%package hook-promisc
Summary:        Network interface promiscuous mode support for VDSM
BuildArch:      noarch

%description hook-promisc
VDSM promiscuous mode let user define a VM interface that will capture
all network traffic.

%package hook-qemucmdline
Summary:        QEMU cmdline hook for VDSM
BuildArch:      noarch
Requires:       %{name}

%description hook-qemucmdline
Provides support for injecting QEMU cmdline via VDSM hook.
It exploits libvirt's qemu:commandline facility available in the
qemu xml namespace.

%package hook-qos
Summary:        QoS network in/out traffic support for VDSM
BuildArch:      noarch

%description hook-qos
Hook adds QoS in/out traffic to VMs interfaces

%package hook-scratchpad
Summary:        One time disk creation for VDSM
BuildArch:      noarch

%description hook-scratchpad
scratchpad hook for VDSM
Hook creates a disk for a VM onetime usage,
the disk will be erased when the VM destroyed.
VM cannot be migrated when using scratchpad hook

%package hook-smbios
Summary:        Adding custom smbios entries to libvirt domain via VDSM
BuildArch:      noarch

%description hook-smbios
Adding custom smbios entries to libvirt domain via VDSM
such as: vendor, version, date and release

%package hook-spiceoptions
Summary:        To configure spice options for vm
BuildArch:      noarch

%description hook-spiceoptions
This vdsm hook can be used to configure some of
the spice optimization attributes and values..

%package hook-vmfex
Summary:        vmfex support for VDSM
BuildArch:      noarch
Conflicts:      hook-vmfex-dev

%description hook-vmfex
Hook for vmfex.

%package hook-vmfex-dev
Summary:        VM-FEX vNIC support for VDSM
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Conflicts:      hook-vmfex

%description hook-vmfex-dev
Allows to use custom device properties to connect a guest vNIC to a host
VM-FEX Virtual Function (SR-IOV with macvtap mode).

%package hook-vmdisk
Summary:        External disk support for VDSM
BuildArch:      noarch

%description hook-vmdisk
Hook adds additional disk image for a VM (raw or qcow2)

%package hook-ipv6
Summary:        Set IPv6 configuration through custom network properties
BuildArch:      noarch
Requires:       %{name} >= 4.16.7

%description hook-ipv6
VDSM hook used for applying IPv6 configuration through custom network
properties

%package hook-fcoe
Summary:        Hook to enable FCoE support
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       fcoe-utils

%description hook-fcoe
VDSM hook used for configure specified NICs as FCoE interface through custom
network properties

%post hook-fcoe
%systemd_post lldpad.service
%systemd_post fcoe.service

%package hook-vfio-mdev
Summary:        Hook to enable mdev-capable devices.
BuildArch:      noarch

%description hook-vfio-mdev
Hook to use mdev-capable devices through custom properties.

%package hook-cpuflags
Summary:        Hook that modifies guest's CPU flags
BuildArch:      noarch

%description hook-cpuflags
Hook that modifies guest's CPU flags using custom properties.

%if 0%{?with_gluster_mgmt}
%package gluster
Summary:        Gluster Plugin for VDSM
BuildArch:      noarch
Requires: %{name} = %{version}-%{release}
Requires: glusterfs-server >= %{gluster_version}
Requires: glusterfs-api >= %{gluster_version}
Requires: glusterfs-geo-replication >= %{gluster_version}
Requires: glusterfs-events >= %{gluster_version}
Requires: python-magic
%if 0%{?fedora} >= 25
Requires: iproute-tc
Requires: python-blivet1
%else
Requires: python-blivet
%endif
Requires: xfsprogs

%description gluster
Gluster plugin enables VDSM to serve Gluster functionalities.
%endif

%package containers
Summary: Container support for Vdsm
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description containers
Enables VDSM to manage containers alongside virtual machines.

%prep
%setup -q

%build
%if 0%{?enable_autotools}
autoreconf -if
%endif
%configure \
%if 0%{?with_hooks}
        --enable-hooks \
%endif
%if ! 0%{?with_gluster_mgmt}
        --disable-gluster-mgmt \
%endif
%if ! 0%{?with_python3}
        --disable-python3 \
%endif
        --with-smbios-manufacturer='oVirt' \
        --with-smbios-osname='oVirt Node' \
%if ! 0%{?with_ovirt_imageio}
        --disable-ovirt-imageio \
%endif
%if ! 0%{?with_openvswitch}
        --disable-openvswitch \
%endif
%if 0%{?with_ovirt_vmconsole}
        --with-ovirt-vmconsole-user=%{vmcon_user} \
        --with-ovirt-vmconsole-group=%{vmcon_group} \
%else
        --with-ovirt-vmconsole-user='vdsm' \
        --with-ovirt-vmconsole-group='kvm' \
%endif
%if 0%{?with_containers}
        --enable-containers \
%endif
        --with-data-center='/rhev/data-center' \
        --with-polkitdir=%{_polkitdir}

make
# Setting software_version and software_revision in dsaversion.py
baserelease=`echo "%{release}" | sed 's/\([0-9]\+\(\.[0-9]\+\)\?\).*/\1/'`
baseversion=`echo "%{version}" | sed 's/\([0-9]\+\(\.[0-9]\+\)\?\).*/\1/'`
rawversion=%{version}-%{release}
sed -i -e 's/^software_version =.*/software_version = "'"${baseversion}"'"/' \
       -e 's/^raw_version_revision =.*/raw_version_revision = "'"${rawversion}"'"/' \
       -e 's/^software_revision =.*/software_revision = "'"${baserelease}"'"/' lib/vdsm/dsaversion.py

%install
make DESTDIR=%{buildroot} install

# Creating VDSM logs in this session to avoid rpmbuild
# complain during the build
install -dDm 0755 %{buildroot}/var/log/vdsm
touch %{buildroot}/var/log/vdsm/{mom.log,supervdsm.log,vdsm.log}

%if 0%{?rhel}
# This is not commonplace, but we want /var/log/core to be a world-writable
# dropbox for core dumps
install -dDm 1777 %{buildroot}%{_localstatedir}/log/core
%endif

%pre
# Force standard locale behavior (English)
export LC_ALL=C

/usr/bin/getent passwd %{vdsm_user} >/dev/null || \
    /usr/sbin/useradd -r -u 36 -g %{vdsm_group} -d /var/lib/vdsm \
        -s /sbin/nologin -c "Node Virtualization Manager" %{vdsm_user}
/usr/sbin/usermod -a -G %{qemu_group},%{snlk_group} %{vdsm_user}
/usr/sbin/usermod -a -G %{cdrom_group} %{qemu_user}

# We keep the previous rpm version number in a file for managing upgrade flow
if [ "$1" -gt 1 ]; then
    rpm -q %{vdsm_name} > "%{_localstatedir}/lib/%{vdsm_name}/upgraded_version"
fi

%post
# After vdsm install we should create the logs files.
# In the install session we create it but since we use
# the ghost macro (in files session) the files are not included
touch /var/log/vdsm/{mom.log,supervdsm.log,vdsm.log}
chmod 0644 /var/log/vdsm/{mom.log,supervdsm.log,vdsm.log}
chown vdsm:kvm /var/log/vdsm/{mom.log,vdsm.log}
chown root:root /var/log/vdsm/supervdsm.log

systemd-tmpfiles --create %{vdsm_name}.conf

# Have moved vdsm section in /etc/sysctl.conf to /etc/sysctl.d/vdsm.conf.
# So Remove them if it is played with /etc/sysctl.conf.
if grep -q "# VDSM section begin" /etc/sysctl.conf; then
    /bin/sed -i '/# VDSM section begin/,/# VDSM section end/d' \
        /etc/sysctl.conf
fi

# VDSM installs vdsm-modules-load.d.conf file - the following command will
# refresh vdsm kernel modules requirements to start on boot
/bin/systemctl restart systemd-modules-load.service >/dev/null 2>&1 || :

# The following triggers vdsmd.preset file and enables vdsm required services
%systemd_post dev-hugepages1G.mount
%systemd_post vdsmd.service
%systemd_post supervdsmd.service
%systemd_post vdsm-network.service
%systemd_post vdsm-network-init.service
%systemd_post mom-vdsm.service
%systemd_post ksmtuned.service

# VDSM installs unit files - daemon-reload will refresh systemd
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
exit 0

%preun
if [ "$1" -eq 0 ]; then
        %{_bindir}/vdsm-tool remove-config
fi
%systemd_preun dev-hugepages1G.mount
%systemd_preun vdsmd.service
%systemd_preun vdsm-network.service
%systemd_preun vdsm-network-init.service
%systemd_preun supervdsmd.service
%systemd_preun mom-vdsm.service
%systemd_preun ksmtuned.service
exit 0

%posttrans
if  [ -f "%{_localstatedir}/lib/%{vdsm_name}/upgraded_version" ]; then
    supervdsmd_start_required='no'
    vdsmd_start_required='no'

    # Both vdsm and supervdsm should be managed here and must be restarted if
    # ran before (code might changed)
    if /bin/systemctl status vdsmd >/dev/null 2>&1; then
        /bin/systemctl stop vdsmd >/dev/null 2>&1 || :
        vdsmd_start_required='yes'
    fi
    if /bin/systemctl status supervdsmd >/dev/null 2>&1; then
        /bin/systemctl stop supervdsmd >/dev/null 2>&1 || :
        supervdsmd_start_required='yes'
    fi
    if /bin/systemctl status vdsm-network >/dev/null 2>&1; then
        /bin/systemctl stop vdsm-network >/dev/null 2>&1 || :
    fi

    if ! %{_bindir}/vdsm-tool is-configured >/dev/null 2>&1; then
        %{_bindir}/vdsm-tool configure --force >/dev/null 2>&1
    fi

    if [ "${supervdsmd_start_required}" = 'yes' ]; then
        /bin/systemctl start supervdsmd >/dev/null 2>&1 || :
    fi
    if [ "${vdsmd_start_required}" = 'yes' ]; then
        /bin/systemctl start vdsmd >/dev/null 2>&1 || :
    fi
    /bin/rm -f "%{_localstatedir}/lib/%{vdsm_name}/upgraded_version"
fi
exit 0

%files
%doc README.md
%doc lib/vdsm/vdsm.conf.sample
%doc README.logging
%license COPYING
%{_presetdir}/85-vdsmd.preset
%{_unitdir}/dev-hugepages1G.mount
%{_unitdir}/vdsmd.service
%{_unitdir}/vdsm-network.service
%{_unitdir}/vdsm-network-init.service
%{_unitdir}/supervdsmd.service
%{_unitdir}/mom-vdsm.service
%{_sysconfdir}/systemd/system/libvirtd.service.d/unlimited-core.conf

%dir %attr(-, %{vdsm_user}, %{vdsm_group}) /rhev/data-center
%ghost %config %attr(0644, %{vdsm_user}, %{vdsm_group}) /var/log/vdsm/mom.log
%ghost %config %attr(0644, root, root) /var/log/vdsm/supervdsm.log
%ghost %config %attr(0644, %{vdsm_user}, %{vdsm_group}) /var/log/vdsm/vdsm.log
%ghost %dir %attr(-, %{vdsm_user}, %{vdsm_group}) /rhev/data-center/hsm-tasks
%ghost %dir %attr(-, %{vdsm_user}, %{vdsm_group}) /rhev/data-center/mnt
%dir %{_libexecdir}/%{vdsm_name}
%dir %{_sysconfdir}/%{vdsm_name}/vdsm.conf.d
%dir %{_sysconfdir}/modprobe.d/
%dir %{_sysconfdir}/NetworkManager
%dir %{_sysconfdir}/NetworkManager/conf.d
%dir %{_sysconfdir}/%{vdsm_name}
%dir %{_sysconfdir}/%{vdsm_name}/mom.d
%dir %{_datadir}/%{vdsm_name}
%{_datadir}/%{vdsm_name}/daemonAdapter
%{_datadir}/%{vdsm_name}/sitecustomize.py*
%{_datadir}/%{vdsm_name}/supervdsmd
%{_datadir}/%{vdsm_name}/vdsmd

%config(noreplace) %{_sysconfdir}/%{vdsm_name}/vdsm.conf
%config(noreplace) %{_sysconfdir}/%{vdsm_name}/logger.conf
%config(noreplace) %{_sysconfdir}/%{vdsm_name}/svdsm.logger.conf
%config(noreplace) %{_sysconfdir}/%{vdsm_name}/mom.conf
%config(noreplace) %{_sysconfdir}/%{vdsm_name}/mom.d/*.policy
%config(noreplace) %{_sysconfdir}/%{vdsm_name}/logrotate/vdsm
%config(noreplace) %{_sysconfdir}/sysctl.d/vdsm.conf
%config(noreplace) %{_sysconfdir}/modules-load.d/vdsm.conf
%{_tmpfilesdir}/%{vdsm_name}.conf
%{_sysconfdir}/dhcp/dhclient.d/dhclientmon.sh
%{_sysconfdir}/modprobe.d/vdsm-bonding-modprobe.conf
%{_sysconfdir}/NetworkManager/conf.d/vdsm.conf
%{_sysconfdir}/sudoers.d/50_vdsm
%{_sysconfdir}/cron.hourly/vdsm-logrotate
%{_sysconfdir}/libvirt/hooks/qemu
%{_libexecdir}/%{vdsm_name}/curl-img-wrap
%{_libexecdir}/%{vdsm_name}/fc-scan
%{_libexecdir}/%{vdsm_name}/vdsm-gencerts.sh
%{_libexecdir}/%{vdsm_name}/vdsmd_init_common.sh
%{_libexecdir}/%{vdsm_name}/vm_migrate_hook.py*
%{_libexecdir}/%{vdsm_name}/kvm2ovirt
%{_libexecdir}/%{vdsm_name}/fallocate
%{_libexecdir}/%{vdsm_name}/wait_for_ipv4s
%{_libexecdir}/%{vdsm_name}/spmprotect.sh
%{_libexecdir}/%{vdsm_name}/spmstop.sh
%dir %{_libexecdir}/%{vdsm_name}/hooks
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_device_create
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_device_create
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_device_destroy
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_device_destroy
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_start
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_start
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_cont
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_cont
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_pause
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_pause
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_hibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_hibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_dehibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_dehibernate
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_device_migrate_source
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_device_migrate_source
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_device_migrate_destination
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_device_migrate_destination
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_source
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_migrate_source
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_destination
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_migrate_destination
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_destroy
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vm_set_ticket
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vm_set_ticket
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_update_device
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_update_device
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_update_device_fail
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotunplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotunplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotplug_fail
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotunplug_fail
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_disk_prepare
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_disk_hotplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_disk_hotplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_disk_hotunplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_disk_hotunplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_vdsm_start
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_vdsm_stop
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_network_setup
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_network_setup
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_network_setup_fail
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_set_num_of_cpus
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_set_num_of_cpus
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_memory_hotplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_memory_hotplug
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_get_vm_stats
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_get_vm_stats
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_get_all_vm_stats
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_get_all_vm_stats
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_get_caps
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_get_caps
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_get_stats
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_get_stats
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_hostdev_list_by_caps
%dir %{_libexecdir}/%{vdsm_name}/hooks/before_ifcfg_write
%dir %{_libexecdir}/%{vdsm_name}/hooks/after_ifcfg_write

%{_libexecdir}/%{vdsm_name}/get-conf-item
%{_libexecdir}/%{vdsm_name}/set-conf-item
%{python_sitelib}/sos/plugins/vdsm.py*
%{_udevrulesdir}/12-vdsm-lvm.rules
/etc/security/limits.d/99-vdsm.conf
%{_mandir}/man8/vdsmd.8*
%if 0%{?rhel}
%dir %{_localstatedir}/log/core
%endif
%{_polkitdir}/10-vdsm-libvirt-access.rules

%defattr(-, %{vdsm_user}, %{qemu_group}, -)
%dir %{_localstatedir}/lib/libvirt/qemu/channels

%defattr(-, %{vdsm_user}, %{vdsm_group}, -)
%dir %{_sysconfdir}/pki/%{vdsm_name}
%dir %{_sysconfdir}/pki/%{vdsm_name}/keys
%dir %{_sysconfdir}/pki/%{vdsm_name}/certs
%dir %{_sysconfdir}/pki/%{vdsm_name}/libvirt-spice
%config(noreplace) %{_sysconfdir}/pki/%{vdsm_name}/keys/libvirt_password
%dir %{_localstatedir}/lib/%{vdsm_name}
%dir %{_localstatedir}/lib/%{vdsm_name}/netconfback
%dir %{_localstatedir}/lib/%{vdsm_name}/persistence
%dir %{_localstatedir}/lib/%{vdsm_name}/staging
%dir %{_localstatedir}/lib/%{vdsm_name}/upgrade
%dir %{_localstatedir}/log/%{vdsm_name}
%dir %{_localstatedir}/log/%{vdsm_name}/backup
%dir %{_localstatedir}/log/%{vdsm_name}/import
%defattr(644, %{vdsm_user}, %{vdsm_group}, -)
%{_datadir}/%{vdsm_name}/lvmlocal.conf
%{_datadir}/%{vdsm_name}/autounattend/Win7.xml
%{_datadir}/%{vdsm_name}/autounattend/Win8.xml
%{_datadir}/%{vdsm_name}/autounattend/Win8.1.xml
%{_datadir}/%{vdsm_name}/autounattend/Win10.xml
%{_datadir}/%{vdsm_name}/autounattend/Win2008.xml
%{_datadir}/%{vdsm_name}/autounattend/Win2008R2.xml
%{_datadir}/%{vdsm_name}/autounattend/Win2012.xml
%{_datadir}/%{vdsm_name}/autounattend/Win2012R2.xml
%{_datadir}/%{vdsm_name}/autounattend/Win2016.xml

%files python
%{_mandir}/man1/vdsm-tool.1*
%{_bindir}/vdsm-tool
%dir %{python_sitelib}/%{vdsm_name}
%dir %{python_sitelib}/%{vdsm_name}/common
%dir %{python_sitelib}/%{vdsm_name}/common/network
%dir %{python_sitelib}/%{vdsm_name}/gluster
%dir %{python_sitelib}/%{vdsm_name}/host
%dir %{python_sitelib}/%{vdsm_name}/network
%dir %{python_sitelib}/%{vdsm_name}/network/configurators
%dir %{python_sitelib}/%{vdsm_name}/network/ip
%dir %{python_sitelib}/%{vdsm_name}/network/ip/address
%dir %{python_sitelib}/%{vdsm_name}/network/ip/route
%dir %{python_sitelib}/%{vdsm_name}/network/ip/rule
%dir %{python_sitelib}/%{vdsm_name}/network/link
%dir %{python_sitelib}/%{vdsm_name}/network/link/bond
%dir %{python_sitelib}/%{vdsm_name}/network/netinfo
%dir %{python_sitelib}/%{vdsm_name}/network/netlink
%dir %{python_sitelib}/%{vdsm_name}/network/netswitch
%dir %{python_sitelib}/%{vdsm_name}/network/nm
%dir %{python_sitelib}/%{vdsm_name}/network/nm/nmdbus
%dir %{python_sitelib}/%{vdsm_name}/network/ovs
%dir %{python_sitelib}/%{vdsm_name}/network/ovs/driver
%dir %{python_sitelib}/%{vdsm_name}/network/tc
%dir %{python_sitelib}/%{vdsm_name}/metrics
%dir %{python_sitelib}/%{vdsm_name}/tool
%dir %{python_sitelib}/%{vdsm_name}/tool/configurators
%dir %{python_sitelib}/%{vdsm_name}/profiling
%dir %{python_sitelib}/%{vdsm_name}/storage
%dir %{python_sitelib}/%{vdsm_name}/supervdsm_api
%dir %{python_sitelib}/%{vdsm_name}/virt
%dir %{python_sitelib}/%{vdsm_name}/virt/vmdevices
%{python_sitelib}/%{vdsm_name}/__init__.py*
%{python_sitelib}/%{vdsm_name}/alignmentScan.py*
%{python_sitelib}/%{vdsm_name}/API.py*
%{python_sitelib}/%{vdsm_name}/client.py*
%{python_sitelib}/%{vdsm_name}/clientIF.py*
%{python_sitelib}/%{vdsm_name}/cmdutils.py*
%{python_sitelib}/%{vdsm_name}/commands.py*
%{python_sitelib}/%{vdsm_name}/common/*.py*
%{python_sitelib}/%{vdsm_name}/hook/*.py*
%{python_sitelib}/%{vdsm_name}/host/*.py*
%{python_sitelib}/%{vdsm_name}/common/network/*.py*
%{python_sitelib}/%{vdsm_name}/config.py*
%{python_sitelib}/%{vdsm_name}/constants.py*
%{python_sitelib}/%{vdsm_name}/containersconnection.py*
%{python_sitelib}/%{vdsm_name}/cpuarch.py*
%{python_sitelib}/%{vdsm_name}/cpuinfo.py*
%{python_sitelib}/%{vdsm_name}/dsaversion.py*
%{python_sitelib}/%{vdsm_name}/dmidecodeUtil.py*
%{python_sitelib}/%{vdsm_name}/executor.py*
# gluster.exception is used in many places like Bridge.py. So it is required
# even without vdsm-gluster package
%{python_sitelib}/%{vdsm_name}/gluster/__init__.py*
%{python_sitelib}/%{vdsm_name}/gluster/cli.py*
%{python_sitelib}/%{vdsm_name}/gluster/exception.py*
%{python_sitelib}/%{vdsm_name}/health.py*
%{python_sitelib}/%{vdsm_name}/hooks.py*
%{python_sitelib}/%{vdsm_name}/hostdev.py*
%{python_sitelib}/%{vdsm_name}/hugepages.py*
%{python_sitelib}/%{vdsm_name}/jobs.py*
%{python_sitelib}/%{vdsm_name}/jsonrpcvdscli.py*
%{python_sitelib}/%{vdsm_name}/kvm2ovirt.py*
%{python_sitelib}/%{vdsm_name}/libvirtconnection.py*
%{python_sitelib}/%{vdsm_name}/logUtils.py*
%{python_sitelib}/%{vdsm_name}/machinetype.py*
%{python_sitelib}/%{vdsm_name}/metrics/*.py*
%{python_sitelib}/%{vdsm_name}/moduleloader.py*
%{python_sitelib}/%{vdsm_name}/momIF.py*
%{python_sitelib}/%{vdsm_name}/mkimage.py*
%{python_sitelib}/%{vdsm_name}/network/__init__.py*
%{python_sitelib}/%{vdsm_name}/network/api.py*
%{python_sitelib}/%{vdsm_name}/network/configurators/__init__.py*
%{python_sitelib}/%{vdsm_name}/network/configurators/ifcfg.py*
%{python_sitelib}/%{vdsm_name}/network/configurators/ifcfg_acquire.py*
%{python_sitelib}/%{vdsm_name}/network/configurators/qos.py*
%{python_sitelib}/%{vdsm_name}/network/errors.py*
%{python_sitelib}/%{vdsm_name}/network/canonicalize.py*
%{python_sitelib}/%{vdsm_name}/network/cmd.py*
%{python_sitelib}/%{vdsm_name}/network/connectivity.py*
%{python_sitelib}/%{vdsm_name}/network/dhclient_monitor.py*
%{python_sitelib}/%{vdsm_name}/network/driverloader.py*
%{python_sitelib}/%{vdsm_name}/network/ip/*.py*
%{python_sitelib}/%{vdsm_name}/network/ip/address/*.py*
%{python_sitelib}/%{vdsm_name}/network/ip/route/*.py*
%{python_sitelib}/%{vdsm_name}/network/ip/rule/*.py*
%{python_sitelib}/%{vdsm_name}/network/ifacetracking.py*
%{python_sitelib}/%{vdsm_name}/network/ifacquire.py*
%{python_sitelib}/%{vdsm_name}/network/initializer.py*
%{python_sitelib}/%{vdsm_name}/network/ipwrapper.py*
%{python_sitelib}/%{vdsm_name}/network/link/*.py*
%{python_sitelib}/%{vdsm_name}/network/link/bond/*.py*
%{python_sitelib}/%{vdsm_name}/network/kernelconfig.py*
%{python_sitelib}/%{vdsm_name}/network/legacy_switch.py*
%{python_sitelib}/%{vdsm_name}/network/netinfo/*.py*
%{python_sitelib}/%{vdsm_name}/network/netlink/__init__.py*
%{python_sitelib}/%{vdsm_name}/network/netlink/addr.py*
%{python_sitelib}/%{vdsm_name}/network/netlink/libnl.py*
%{python_sitelib}/%{vdsm_name}/network/netlink/link.py*
%{python_sitelib}/%{vdsm_name}/network/netlink/monitor.py*
%{python_sitelib}/%{vdsm_name}/network/netlink/route.py*
%{python_sitelib}/%{vdsm_name}/network/netlink/waitfor.py*
%{python_sitelib}/%{vdsm_name}/network/netswitch/*.py*
%{python_sitelib}/%{vdsm_name}/network/nm/*.py*
%{python_sitelib}/%{vdsm_name}/network/nm/nmdbus/*.py*
%{python_sitelib}/%{vdsm_name}/network/ovs/__init__.py*
%{python_sitelib}/%{vdsm_name}/network/ovs/info.py*
%{python_sitelib}/%{vdsm_name}/network/ovs/switch.py*
%{python_sitelib}/%{vdsm_name}/network/ovs/validator.py*
%{python_sitelib}/%{vdsm_name}/network/ovs/driver/__init__.py*
%{python_sitelib}/%{vdsm_name}/network/ovs/driver/vsctl.py*
%{python_sitelib}/%{vdsm_name}/network/models.py*
%{python_sitelib}/%{vdsm_name}/network/netconfpersistence.py*
%{python_sitelib}/%{vdsm_name}/network/netrestore.py*
%{python_sitelib}/%{vdsm_name}/network/netupgrade.py*
%{python_sitelib}/%{vdsm_name}/network/py2to3.py*
%{python_sitelib}/%{vdsm_name}/network/restore_net_config.py*
%{python_sitelib}/%{vdsm_name}/network/sourceroute.py*
%{python_sitelib}/%{vdsm_name}/network/sysctl.py*
%{python_sitelib}/%{vdsm_name}/network/tc/__init__.py*
%{python_sitelib}/%{vdsm_name}/network/tc/_parser.py*
%{python_sitelib}/%{vdsm_name}/network/tc/_wrapper.py*
%{python_sitelib}/%{vdsm_name}/network/tc/cls.py*
%{python_sitelib}/%{vdsm_name}/network/tc/filter.py*
%{python_sitelib}/%{vdsm_name}/network/tc/qdisc.py*
%{python_sitelib}/%{vdsm_name}/numa.py*
%{python_sitelib}/%{vdsm_name}/osinfo.py*
%{python_sitelib}/%{vdsm_name}/panic.py*
%{python_sitelib}/%{vdsm_name}/ppc64HardwareInfo.py*
%{python_sitelib}/%{vdsm_name}/profiling/__init__.py*
%{python_sitelib}/%{vdsm_name}/profiling/cpu.py*
%{python_sitelib}/%{vdsm_name}/profiling/errors.py*
%{python_sitelib}/%{vdsm_name}/profiling/memory.py*
%{python_sitelib}/%{vdsm_name}/profiling/profile.py*
%{python_sitelib}/%{vdsm_name}/storage/__init__.py*
%{python_sitelib}/%{vdsm_name}/storage/asyncevent.py*
%{python_sitelib}/%{vdsm_name}/storage/asyncutils.py*
%{python_sitelib}/%{vdsm_name}/storage/blkdiscard.py*
%{python_sitelib}/%{vdsm_name}/storage/blockdev.py*
%{python_sitelib}/%{vdsm_name}/storage/blockSD.py*
%{python_sitelib}/%{vdsm_name}/storage/blockVolume.py*
%{python_sitelib}/%{vdsm_name}/storage/check.py*
%{python_sitelib}/%{vdsm_name}/storage/clusterlock.py*
%{python_sitelib}/%{vdsm_name}/storage/compat.py*
%{python_sitelib}/%{vdsm_name}/storage/constants.py*
%{python_sitelib}/%{vdsm_name}/storage/curlImgWrap.py*
%{python_sitelib}/%{vdsm_name}/storage/devicemapper.py*
%{python_sitelib}/%{vdsm_name}/storage/directio.py*
%{python_sitelib}/%{vdsm_name}/storage/dispatcher.py*
%{python_sitelib}/%{vdsm_name}/storage/exception.py*
%{python_sitelib}/%{vdsm_name}/storage/fallocate.py*
%{python_sitelib}/%{vdsm_name}/storage/fileSD.py*
%{python_sitelib}/%{vdsm_name}/storage/fileUtils.py*
%{python_sitelib}/%{vdsm_name}/storage/fileVolume.py*
%{python_sitelib}/%{vdsm_name}/storage/formatconverter.py*
%{python_sitelib}/%{vdsm_name}/storage/fuser.py*
%{python_sitelib}/%{vdsm_name}/storage/fsutils.py*
%{python_sitelib}/%{vdsm_name}/storage/glusterSD.py*
%{python_sitelib}/%{vdsm_name}/storage/glusterVolume.py*
%{python_sitelib}/%{vdsm_name}/storage/guarded.py*
%{python_sitelib}/%{vdsm_name}/storage/hba.py*
%{python_sitelib}/%{vdsm_name}/storage/hsm.py*
%{python_sitelib}/%{vdsm_name}/storage/image.py*
%{python_sitelib}/%{vdsm_name}/storage/imageSharing.py*
%{python_sitelib}/%{vdsm_name}/storage/imagetickets.py*
%{python_sitelib}/%{vdsm_name}/storage/iscsi.py*
%{python_sitelib}/%{vdsm_name}/storage/iscsiadm.py*
%{python_sitelib}/%{vdsm_name}/storage/localFsSD.py*
%{python_sitelib}/%{vdsm_name}/storage/lvm.env
%{python_sitelib}/%{vdsm_name}/storage/lvm.py*
%{python_sitelib}/%{vdsm_name}/storage/mailbox.py*
%{python_sitelib}/%{vdsm_name}/storage/merge.py*
%{python_sitelib}/%{vdsm_name}/storage/misc.py*
%{python_sitelib}/%{vdsm_name}/storage/monitor.py*
%{python_sitelib}/%{vdsm_name}/storage/mount.py*
%{python_sitelib}/%{vdsm_name}/storage/multipath.py*
%{python_sitelib}/%{vdsm_name}/storage/nfsSD.py*
%{python_sitelib}/%{vdsm_name}/storage/operation.py*
%{python_sitelib}/%{vdsm_name}/storage/outOfProcess.py*
%{python_sitelib}/%{vdsm_name}/storage/persistent.py*
%{python_sitelib}/%{vdsm_name}/storage/qcow2.py*
%{python_sitelib}/%{vdsm_name}/storage/qemuimg.py*
%{python_sitelib}/%{vdsm_name}/storage/resourceFactories.py*
%{python_sitelib}/%{vdsm_name}/storage/resourceManager.py*
%{python_sitelib}/%{vdsm_name}/storage/rwlock.py*
%{python_sitelib}/%{vdsm_name}/storage/sd.py*
%{python_sitelib}/%{vdsm_name}/storage/sdc.py*
%{python_sitelib}/%{vdsm_name}/storage/securable.py*
%{python_sitelib}/%{vdsm_name}/storage/sp.py*
%{python_sitelib}/%{vdsm_name}/storage/spbackends.py*
%{python_sitelib}/%{vdsm_name}/storage/storageServer.py*
%{python_sitelib}/%{vdsm_name}/storage/sysfs.py*
%{python_sitelib}/%{vdsm_name}/storage/task.py*
%{python_sitelib}/%{vdsm_name}/storage/taskManager.py*
%{python_sitelib}/%{vdsm_name}/storage/threadPool.py*
%{python_sitelib}/%{vdsm_name}/storage/types.py*
%{python_sitelib}/%{vdsm_name}/storage/volume.py*
%{python_sitelib}/%{vdsm_name}/storage/volumemetadata.py*
%{python_sitelib}/%{vdsm_name}/storage/workarounds.py*
%{python_sitelib}/%{vdsm_name}/storage/xlease.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/__init__.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/volume_artifacts.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/volume_info.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/__init__.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/amend_volume.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/base.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/copy_data.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/create_volume.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/merge.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/move_device.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/reduce_domain.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/sparsify_volume.py*
%{python_sitelib}/%{vdsm_name}/storage/sdm/api/update_volume.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/__init__.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/hwinfo.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/mkimage.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/ksm.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/network.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/systemd.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/test.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/udev.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_api/virt.py*
%{python_sitelib}/%{vdsm_name}/protocoldetector.py*
%{python_sitelib}/%{vdsm_name}/schedule.py*
%{python_sitelib}/%{vdsm_name}/sslutils.py*
%{python_sitelib}/%{vdsm_name}/supervdsm.py*
%{python_sitelib}/%{vdsm_name}/supervdsm_server.py*
%{python_sitelib}/%{vdsm_name}/taskset.py*
%{python_sitelib}/%{vdsm_name}/throttledlog.py*
%{python_sitelib}/%{vdsm_name}/udevadm.py*
%{python_sitelib}/%{vdsm_name}/utils.py*
%{python_sitelib}/%{vdsm_name}/v2v.py*
%{python_sitelib}/%{vdsm_name}/vdsmd.py*
%{python_sitelib}/%{vdsm_name}/virtsparsify.py*
%{python_sitelib}/%{vdsm_name}/virtsysprep.py*
%{python_sitelib}/%{vdsm_name}/tool/__init__.py*
%{python_sitelib}/%{vdsm_name}/tool/configfile.py*
%{python_sitelib}/%{vdsm_name}/tool/confmeta.py*
%{python_sitelib}/%{vdsm_name}/tool/confutils.py*
%{python_sitelib}/%{vdsm_name}/tool/dummybr.py*
%{python_sitelib}/%{vdsm_name}/tool/nwfilter.py*
%{python_sitelib}/%{vdsm_name}/tool/configurator.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/__init__*
%{python_sitelib}/%{vdsm_name}/tool/configurators/abrt.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/certificates.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/libvirt.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/lvm.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/passwd.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/sanlock.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/sebool.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/multipath.py*
%{python_sitelib}/%{vdsm_name}/tool/configurators/bond_defaults.py*
%{python_sitelib}/%{vdsm_name}/tool/dump_volume_chains.py*
%{python_sitelib}/%{vdsm_name}/tool/network.py*
%{python_sitelib}/%{vdsm_name}/tool/register.py*
%{python_sitelib}/%{vdsm_name}/tool/service.py*
%{python_sitelib}/%{vdsm_name}/tool/transient.py*
%{python_sitelib}/%{vdsm_name}/tool/upgrade.py*
%{python_sitelib}/%{vdsm_name}/tool/vdsm-id.py*
%{python_sitelib}/%{vdsm_name}/virt/__init__.py*
%{python_sitelib}/%{vdsm_name}/virt/collectd.py*
%{python_sitelib}/%{vdsm_name}/virt/domain_descriptor.py*
%{python_sitelib}/%{vdsm_name}/virt/events.py*
%{python_sitelib}/%{vdsm_name}/virt/guestagent.py*
%{python_sitelib}/%{vdsm_name}/virt/libvirtnetwork.py*
%{python_sitelib}/%{vdsm_name}/virt/libvirtxml.py*
%{python_sitelib}/%{vdsm_name}/virt/metadata.py*
%{python_sitelib}/%{vdsm_name}/virt/migration.py*
%{python_sitelib}/%{vdsm_name}/virt/periodic.py*
%{python_sitelib}/%{vdsm_name}/virt/recovery.py*
%{python_sitelib}/%{vdsm_name}/virt/sampling.py*
%{python_sitelib}/%{vdsm_name}/virt/secret.py*
%{python_sitelib}/%{vdsm_name}/virt/utils.py*
%{python_sitelib}/%{vdsm_name}/virt/virdomain.py*
%{python_sitelib}/%{vdsm_name}/virt/vm.py*
%{python_sitelib}/%{vdsm_name}/virt/jobs/__init__.py*
%{python_sitelib}/%{vdsm_name}/virt/jobs/seal.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/__init__.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/common.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/core.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/graphics.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/hostdevice.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/hwclass.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/lease.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/network.py*
%{python_sitelib}/%{vdsm_name}/virt/vmdevices/storage.py*
%{python_sitelib}/%{vdsm_name}/virt/vmchannels.py*
%{python_sitelib}/%{vdsm_name}/virt/vmexitreason.py*
%{python_sitelib}/%{vdsm_name}/virt/vmpowerdown.py*
%{python_sitelib}/%{vdsm_name}/virt/vmstats.py*
%{python_sitelib}/%{vdsm_name}/virt/vmstatus.py*
%{python_sitelib}/%{vdsm_name}/virt/vmtune.py*
%{python_sitelib}/%{vdsm_name}/virt/vmxml.py*
%{python_sitelib}/%{vdsm_name}/virt/xmlconstants.py*

%files tests
%doc %{_datadir}/%{vdsm_name}/tests/README
%dir %{_datadir}/%{vdsm_name}
%dir %{_datadir}/%{vdsm_name}/tests
%dir %{_datadir}/%{vdsm_name}/tests/common
%if 0%{?with_containers}
%dir %{_datadir}/%{vdsm_name}/tests/containers
%dir %{_datadir}/%{vdsm_name}/tests/containers/data
%dir %{_datadir}/%{vdsm_name}/tests/containers/fake
%dir %{_datadir}/%{vdsm_name}/tests/containers/fake/bin
%endif
%dir %{_datadir}/%{vdsm_name}/tests/cpuinfo
%dir %{_datadir}/%{vdsm_name}/tests/functional
%dir %{_datadir}/%{vdsm_name}/tests/devices
%dir %{_datadir}/%{vdsm_name}/tests/devices/data
%dir %{_datadir}/%{vdsm_name}/tests/devices/parsing
%dir %{_datadir}/%{vdsm_name}/tests/integration
%dir %{_datadir}/%{vdsm_name}/tests/network
%dir %{_datadir}/%{vdsm_name}/tests/network/static
%dir %{_datadir}/%{vdsm_name}/tests/storage
%{_datadir}/%{vdsm_name}/tests/*.py*
%{_datadir}/%{vdsm_name}/tests/cpu_info.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_intel_E5649.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_amd_6274.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_ibm_S822L.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_ibm_S822L_le.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_intel_E31220.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_intel_E5606.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_intel_i73770.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_intel_i73770_nosnap.out
%{_datadir}/%{vdsm_name}/tests/caps_libvirt_multiqemu.out
%{_datadir}/%{vdsm_name}/tests/caps_numactl_4_nodes.out
%{_datadir}/%{vdsm_name}/tests/common/*.py*
%if 0%{?with_containers}
%{_datadir}/%{vdsm_name}/tests/containers/*.py*
%{_datadir}/%{vdsm_name}/tests/containers/data/*.txt
%{_datadir}/%{vdsm_name}/tests/containers/data/*.xml
%{_datadir}/%{vdsm_name}/tests/containers/fake/bin/*
%{_datadir}/%{vdsm_name}/tests/containers/fake/cgroups.tgz
%endif
%{_datadir}/%{vdsm_name}/tests/cpuinfo/*.out
%{_datadir}/%{vdsm_name}/tests/fake-ssh-add
%{_datadir}/%{vdsm_name}/tests/fake-ssh-agent
%{_datadir}/%{vdsm_name}/tests/fake-virt-sysprep
%{_datadir}/%{vdsm_name}/tests/fake-virt-v2v
%{_datadir}/%{vdsm_name}/tests/fake-virt-v2v.out
%{_datadir}/%{vdsm_name}/tests/fake-virt-v2v.err
%{_datadir}/%{vdsm_name}/tests/cpu_map.xml
%{_datadir}/%{vdsm_name}/tests/devices/*.py*
%{_datadir}/%{vdsm_name}/tests/devices/parsing/*.py*
%{_datadir}/%{vdsm_name}/tests/devices/data/*.xml
%{_datadir}/%{vdsm_name}/tests/mem_info.out
%{_datadir}/%{vdsm_name}/tests/network/*.py*
%{_datadir}/%{vdsm_name}/tests/network/ip_route_show_table_all.out
%{_datadir}/%{vdsm_name}/tests/network/netmaskconversions
%{_datadir}/%{vdsm_name}/tests/network/tc_filter_show.out
%{_datadir}/%{vdsm_name}/tests/network/static/*.json
%{_datadir}/%{vdsm_name}/tests/storage/*.py*
%{_datadir}/%{vdsm_name}/tests/storage/*.out
%{_datadir}/%{vdsm_name}/tests/virttests/*.py*
%{_datadir}/%{vdsm_name}/tests/run_tests.sh
%{_datadir}/%{vdsm_name}/tests/toolTests_abrt-action-save-package-data.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_CCPP.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_abrt.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_empty.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_lconf_ssl.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_libvirtd.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_mtab_1g
%{_datadir}/%{vdsm_name}/tests/toolTests_mtab_default
%{_datadir}/%{vdsm_name}/tests/toolTests_mtab_nohugetlbfs
%{_datadir}/%{vdsm_name}/tests/toolTests_qemu_sanlock.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_qemu_ssl.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_vdsm_no_ssl.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_vdsm_ssl.conf
%{_datadir}/%{vdsm_name}/tests/toolTests_vmcore.conf
%{_datadir}/%{vdsm_name}/tests/glusterGeoRepStatus.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeGeoRepConfigList.xml
%{_datadir}/%{vdsm_name}/tests/glusterSnapshotList.xml
%{_datadir}/%{vdsm_name}/tests/glusterSnapshotListEmpty.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeProfileInfo.xml
%{_datadir}/%{vdsm_name}/tests/glusterSnapshotConfig.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeProfileInfoNfs.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeRebalanceStatus.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeRemoveBricksStatus.xml
%{_datadir}/%{vdsm_name}/tests/glusterSnapshotRestore.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeSnapshotList.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeSnapshotListEmpty.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeTasks.xml
%{_datadir}/%{vdsm_name}/tests/glusterVolumeHealInfo.xml
%{_datadir}/%{vdsm_name}/tests/functional/*.py*
%{_datadir}/%{vdsm_name}/tests/functional/*.policy
%{_datadir}/%{vdsm_name}/tests/integration/*.py*

%files hook-openstacknet
%{_sysconfdir}/sudoers.d/50_vdsm_hook_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/after_device_create/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/after_device_create/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/after_device_destroy/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/after_device_destroy/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/after_device_migrate_destination/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/after_device_migrate_destination/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotplug/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotplug/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotunplug/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/after_nic_hotunplug/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_start/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_start/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/before_device_create/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/before_device_create/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/before_device_migrate_destination/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/before_device_migrate_destination/openstacknet_utils.py*
%{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotplug/50_openstacknet
%{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotplug/openstacknet_utils.py*

%files hook-macspoof
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_macspoof
%{_libexecdir}/%{vdsm_name}/hooks/before_device_create/50_macspoof
%{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotplug/50_macspoof

%if 0%{?with_vhostmd}
%files hook-vhostmd
%license COPYING
%{_sysconfdir}/sudoers.d/50_vdsm_hook_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_destination/50_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_dehibernate/50_vhostmd
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy/50_vhostmd
%else
%exclude %{_sysconfdir}/sudoers.d/50_vdsm_hook_vhostmd
%exclude %{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_vhostmd
%exclude %{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_destination/50_vhostmd
%exclude %{_libexecdir}/%{vdsm_name}/hooks/before_vm_dehibernate/50_vhostmd
%exclude %{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy/50_vhostmd
%endif

%files hook-qemucmdline
%license COPYING
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_qemucmdline

%files hook-ethtool-options
%{_libexecdir}/%{vdsm_name}/hooks/after_network_setup/30_ethtool_options

%files hook-ipv6
%{_libexecdir}/%{vdsm_name}/hooks/before_network_setup/50_ipv6

%files hook-localdisk
%{_sysconfdir}/sudoers.d/50_vdsm_hook_localdisk
%{_libexecdir}/%{vdsm_name}/hooks/after_disk_prepare/localdisk
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_source/localdisk
%{_libexecdir}/%{vdsm_name}/localdisk-helper
%{_udevrulesdir}/12-vdsm-localdisk.rules

%files hook-vmfex-dev
%{_libexecdir}/%{vdsm_name}/hooks/before_device_create/50_vmfex
%{_libexecdir}/%{vdsm_name}/hooks/before_device_migrate_destination/50_vmfex
%{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotplug/50_vmfex

%files hook-vfio-mdev
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_vfio_mdev
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy/50_vfio_mdev

%files hook-cpuflags
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_cpuflags

%if 0%{?with_hooks}
%files hook-allocate_net
%{_libexecdir}/%{vdsm_name}/hooks/before_device_create/10_allocate_net

%files hook-checkimages
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/60_checkimages

%files hook-fcoe
%{_presetdir}/85-vdsm-hook-fcoe.preset
%{_libexecdir}/%{vdsm_name}/hooks/before_network_setup/50_fcoe

%files hook-checkips
%{_libexecdir}/%{vdsm_name}/hooks/after_get_stats/10_checkips
%{_libexecdir}/%{vdsm_name}/hooks/checkipsd
%{_libexecdir}/%{vdsm_name}/hooks/after_get_stats/checkips_utils.py*
%{_unitdir}/vdsm-checkips.service

%files hook-extra-ipv4-addrs
%{_libexecdir}/%{vdsm_name}/hooks/after_network_setup/40_extra_ipv4_addrs

%files hook-diskunmap
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_diskunmap

%files hook-fakevmstats
%{_libexecdir}/%{vdsm_name}/hooks/after_get_all_vm_stats/10_fakevmstats

%files hook-fakesriov
%{_libexecdir}/%{vdsm_name}/hooks/after_hostdev_list_by_caps/10_fakesriov
%{_libexecdir}/%{vdsm_name}/hooks/after_get_caps/10_fakesriov

%files hook-fileinject
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_fileinject

%files hook-floppy
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_floppy
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_source/50_floppy

%files hook-hostusb
%{_sysconfdir}/sudoers.d/50_vdsm_hook_hostusb
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_hostusb
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_source/50_hostusb
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy/50_hostusb

%files hook-httpsisoboot
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_httpsisoboot

%files hook-isolatedprivatevlan
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_isolatedprivatevlan
%{_sysconfdir}/libvirt/nwfilter/isolatedprivatevlan-vdsm.xml

%files hook-macbind
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_macbind

%files hook-noipspoof
%{_libexecdir}/%{vdsm_name}/hooks/before_device_create/50_noipspoof
%{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotplug/50_noipspoof

%files hook-extnet
%{_libexecdir}/%{vdsm_name}/hooks/before_device_create/50_extnet
%{_libexecdir}/%{vdsm_name}/hooks/before_nic_hotplug/50_extnet

%files hook-nestedvt
%{_sysconfdir}/modprobe.d/vdsm-nestedvt.conf
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_nestedvt

%files hook-numa
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_numa

%files hook-pincpu
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_pincpu

%files hook-promisc
%{_sysconfdir}/sudoers.d/50_vdsm_hook_promisc
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_start/50_promisc
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_destroy/50_promisc

%files hook-qos
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_qos

%files hook-scratchpad
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_scratchpad
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_source/50_scratchpad
%{_libexecdir}/%{vdsm_name}/hooks/after_vm_destroy/50_scratchpad

%files hook-smbios
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_smbios

%files hook-spiceoptions
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_spiceoptions

%files hook-vmdisk
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_vmdisk

%files hook-vmfex
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_migrate_destination/50_vmfex
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/50_vmfex
%endif

%files http
%dir %{python_sitelib}/%{vdsm_name}
%dir %{python_sitelib}/%{vdsm_name}/rpc
%{python_sitelib}/%{vdsm_name}/rpc/http.py*

%files client
%{_bindir}/vdsm-client
%dir %{python_sitelib}/vdsmclient
%{python_sitelib}/vdsmclient/__init__.py*
%{python_sitelib}/vdsmclient/client.py*
%{python_sitelib}/yajsonrpc/__init__.py*
%{_mandir}/man1/vdsm-client.1*

%files jsonrpc
%dir %{python_sitelib}/%{vdsm_name}
%dir %{python_sitelib}/%{vdsm_name}/rpc
%{python_sitelib}/%{vdsm_name}/rpc/__init__.py*
%{python_sitelib}/%{vdsm_name}/rpc/bindingjsonrpc.py*
%{python_sitelib}/%{vdsm_name}/rpc/Bridge.py*
%{python_sitelib}/yajsonrpc/__init__.py*

%files api
%doc lib/vdsm/api/vdsm-api.html
%dir %{python_sitelib}/%{vdsm_name}
%dir %{python_sitelib}/%{vdsm_name}/api
%dir %{python_sitelib}/%{vdsm_name}/rpc
%{python_sitelib}/%{vdsm_name}/api/*.py*
%{python_sitelib}/%{vdsm_name}/rpc/vdsm-api.yml
%{python_sitelib}/%{vdsm_name}/rpc/vdsm-events.yml
%if ! 0%{?with_gluster_mgmt}
%exclude %{python_sitelib}/%{vdsm_name}/rpc/vdsm-api-gluster.yml
%endif

%files yajsonrpc
%dir %{python_sitelib}/yajsonrpc
%{python_sitelib}/yajsonrpc/betterAsyncore.py*
%{python_sitelib}/yajsonrpc/stomp.py*
%{python_sitelib}/yajsonrpc/stompreactor.py*

%files hook-faqemu
%license COPYING
%{_libexecdir}/%{vdsm_name}/hooks/after_get_caps/10_faqemu
%{_libexecdir}/%{vdsm_name}/hooks/before_vm_start/10_faqemu

%if 0%{?with_gluster_mgmt}
%files gluster
%license COPYING
%dir %{python_sitelib}/%{vdsm_name}
%dir %{python_sitelib}/%{vdsm_name}/rpc
%dir %{python_sitelib}/%{vdsm_name}/gluster
%{python_sitelib}/%{vdsm_name}/gluster/api.py*
%{python_sitelib}/%{vdsm_name}/gluster/apiwrapper.py*
%{python_sitelib}/%{vdsm_name}/gluster/events.py*
%{python_sitelib}/%{vdsm_name}/gluster/fstab.py*
%{python_sitelib}/%{vdsm_name}/gluster/fence.py*
%{python_sitelib}/%{vdsm_name}/gluster/gfapi.py*
%{python_sitelib}/%{vdsm_name}/gluster/hooks.py*
%{python_sitelib}/%{vdsm_name}/gluster/services.py*
%{python_sitelib}/%{vdsm_name}/gluster/storagedev.py*
%{python_sitelib}/%{vdsm_name}/gluster/tasks.py*
%{python_sitelib}/%{vdsm_name}/rpc/vdsm-api-gluster.yml
%endif

%if 0%{?with_containers}
%files containers
%defattr(-, root, root, -)
%dir %{_datadir}/%{vdsm_name}
%dir %{python_sitelib}/%{vdsm_name}
%dir %{python_sitelib}/%{vdsm_name}/virt/containers
%{python_sitelib}/%{vdsm_name}/supervdsm_api/containers.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/__init__.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/cgroups.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/command.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/connection.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/docker.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/domain.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/doms.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/errors.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/events.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/monitoring.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/runner.py*
%{python_sitelib}/%{vdsm_name}/virt/containers/xmlfile.py*
%endif


%changelog
* Fri Aug 25 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.20.2-1
- Rebase on upstream 4.20.2

* Mon Jul 31 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.19.24-1
- Rebase on upstream 4.19.24

* Wed Jul 19 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.19.23-1
- Rebase on upstream 4.19.23

* Tue Jun 27 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.19.20-1
- Rebase on upstream 4.19.20

* Tue May 23 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.19.15-1
- vdsm tag v4.19.15 - oVirt 4.1.2 GA

* Fri Mar 17 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.19.9-1
- vdsm tag v4.19.9 - oVirt 4.1.1 rc3

* Thu Feb 16 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.19.4-1
- vdsm tag v4.19.4 - oVirt 4.1.0 GA

* Fri Jan 27 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.19.3-1
- vdsm tag v4.19.3 - oVirt 4.1.0 rc2

* Tue Jan 10 2017 Rafael Martins <rmartins@redhat.com> - 4.18.21-1
- vdsm tag v4.18.21 - oVirt 4.0.6

* Tue Nov 22 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.15.3-1
- vdsm tag v4.18.15.3 - oVirt 4.0.5 async

* Fri Oct 21 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.15.2-1
- vdsm tag v4.18.15.2 - oVirt 4.0.5 rc3

* Fri Oct 14 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.15.1-1
- vdsm tag v4.18.15.1 - oVirt 4.0.5 rc2

* Thu Sep 15 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.13-1
- vdsm tag v4.18.13 - oVirt 4.0.4 rc2

* Fri Sep  2 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.12-1
- vdsm tag v4.18.12 - oVirt 4.0.4 rc1

* Thu Aug 11 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.11-1
- vdsm tag v4.18.11 - oVirt 4.0.2 rc4

* Wed Aug  3 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.10-1
- vdsm tag v4.18.10 - oVirt 4.0.2 rc3

* Tue Jul 26 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.18.9-1
- vdsm tag v4.18.9 - oVirt 4.0.2 rc2

* Mon Jul 18 2016 Rafael Martins <rmartins@redhat.com> - 4.17.32-1
- vdsm tag 4.17.32 - oVirt 3.6.7

* Tue May 24 2016 Rafael Martins <rmartins@redhat.com> - 4.17.28-1
- vdsm tag 4.17.28 - oVirt 3.6.6

* Fri Apr 22 2016 Rafael Martins <rmartins@redhat.com> - 4.17.26-1
- vdsm tag 4.17.26 - oVirt 3.6.5

* Wed Mar 30 2016 Rafael Martins <rmartins@redhat.com> - 4.17.23.2-1
- vdsm tag 4.17.23.2 - oVirt 3.6.4

* Tue Mar  1 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.23-1
- vdsm tag 4.17.23 - oVirt 3.6.3

* Wed Jan 20 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.18-1
- vdsm tag 4.17.18 - oVirt 3.6.2

* Fri Dec 11 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.13-1
- vdsm tag 4.17.13 - oVirt 3.6.1

* Wed Nov 25 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.11-1
- vdsm tag 4.17.11 - oVirt 3.6.1

* Thu Nov  5 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.10.1-1
- vdsm tag 4.17.10.1 - oVirt 3.6.0

* Fri Oct 23 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.10-1
- vdsm tag 4.17.10 - oVirt 3.6.0

* Tue Sep 22 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.8-1
- vdsm tag 4.17.8 - oVirt 3.6.0 Beta 7

* Fri Sep 11 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.6-1
- vdsm tag 4.17.6 - oVirt 3.6.0 Beta 5

* Tue Sep  8 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.5-1
- vdsm tag 4.17.5 - oVirt 3.6.0 Beta 4

* Wed Sep  2 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.4-1
- vdsm tag 4.17.4 - oVirt 3.6.0 Beta 4

* Fri Aug 21 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.17.3-1
- vdsm tag 4.17.3 - oVirt 3.6.0 Beta 3

* Fri Aug 21 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.25-1
- vdsm tag 4.16.25 - oVirt 3.5.4

* Tue Aug  4 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.24-1
- vdsm tag 4.16.24 -oVirt 3.5.4

* Mon Jul 27 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.23-1
- vdsm tag 4.16.23 -oVirt 3.5.4

* Wed Jul 15 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.22-1
- vdsm tag 4.16.22 -oVirt 3.5.4

* Thu Jul  2 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.21-1
- vdsm tag 4.16.21 -oVirt 3.5.4

* Mon Jun  8 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.20-1
- vdsm tag 4.16.20 -oVirt 3.5.3 RC3 build

* Thu May 28 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.18-1
- vdsm tag 4.16.18 -oVirt 3.5.3 RC2 build

* Fri May 08 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.16-1
- vdsm tag 4.16.16 -oVirt 3.5.3 RC1 build

* Fri May 08 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.16.14-1
- vdsm tag 4.16.14 -oVirt 3.5.2 build

* Thu Dec 25 2014 Yaniv Bronhaim <ybronhei@redhat.com> - 4.16.10
* vdsm tag 4.16.10 - ovirt 3.5 build

* Wed Oct 8 2014 Yaniv Bronhaim <ybronhei@redhat.com> - 4.16.7
- vdsm tag 4.16.7

* Sun Sep 28 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.16.5-5
- vdsm tag 4.16.5-5

* Wed Sep 10 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.16.4-0
- vdsm tag 4.16.4

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.16.0-7.git5d3ed2d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jun 30 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.16.0-6.git5d3ed2d
- vdsm 4.16.0-6.git5d3ed2d

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.14.8.1-1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 07 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.8.1-0
- vdsm tag 4.14.8.1

* Thu Apr 24 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.7-0
- vdsm tag 4.14.7-0

* Tue Mar 25 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.6-0
- vdsm tag 4.14.6-0

* Sun Mar 09 2014 Yaniv Bronhaim <ybronhei@redhat.com> - 4.14.5-0
- Adding patches until 4.14.5 tag
- Urgent fix for 4.14.4 that included http-1.1 support for python 2.6 -
xmlrpc: [Fix] Use correct base class for parsing request

* Mon Feb 10 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.2-0
- vdsm 4.14.2-0

* Thu Feb 06 2014 Yaniv Bronhaim <ybronhei@redhat.com - 4.14.1-4
- Adding configure sanlock on force

* Wed Feb 05 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.1-3
- execCmd with sudo=root raise require tty fault when running as root
- sysvinit: Ensure that iscsid is started (BZ#1056948)
- Add missing libnl buildrequires dependency
- vdsm.spec: vdsm-python requires python-cpopen
- netconfig: set ETHTOOL_OPTS when a NIC goes up (BZ#1059680)
- sos: plugin should ignore /var/run/vdsm/storage
- vdsm.spec: vdsm should own vdsm.log (BZ#1055153)
- vdsm.spec: own metadata supervdsm mom logs (BZ#1055153)
- spec: do not remove vdsm logs when pkg removed (BZ#1055153)
- gluster: add host uuid in volume status
- gluster: interpret and use correct xml elements
- gluster: adopt xml changes of rebalance and remove-brick status
- vm: do not pause during refreshVolume (BZ#889097)
- spec: vdsm pkg for EL distro must include pkla (BZ#1060524)

* Tue Jan 21 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.1-2
- vdsm.spec: Add BuildRequires to python-argparse

* Mon Jan 20 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.1-1
- Rebuild 4.14.1 from ovirt-3.4

* Mon Jan 20 2014 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.14.1-0
- Build 4.14.1-0

* Mon Jan 13 2014 Yaniv Bronhaim <ybronhei@redhat.com> - 4.13.3-1
- Reverting iscsi changes that caused a regression by importing
zombieReaper package which was not backported

* Mon Jan 13 2014 Yaniv Bronhaim <ybronhei@redhat.com> - 4.13.3
- spec: bumping iscsi-initiator-utils requirement
- removing redundant check-local from storage makefile
- Adding exception handling in external threads
- fix bridgeless broken network deletion
- gluster api fix
- fix log issues - Changed BrokerLink log level to prevent log flooding
- sampling: make HostStatsThread a daemon thread
- bugfix - BindingXMLRpc - Return lastClientIface for current connection
- vm: Bring back missing before_device_migrate_source hook call
- update NIC: having no custom properies is valid
- prepareVolumePath payload misdetection fix
- fileSD: Fix image deletion on gluster domain
- vm: Update domains list for disks attached to vm after LSM
- prepareVolumePath correct path handling for cdrom

* Wed Dec 11 2013 Yaniv Bronhaim <ybronhei@redhat.com> - 4.13.2-1
- fix cpopen obsolete loop
- fix threadPool refs
- mom policy fixes
- restorecon hack in spec file
- domainMonitor fixed last check flow

* Tue Dec 10 2013 Yaniv Bronhaim <ybronhei@redhat.com> - 4.13.2-0
- Bumping minor version due to recent merge of ovirt-3.3 patches

* Thu Nov 28 2013 Yaniv Bronhaim <ybronhei@redhat.com> - 4.13.0-14
- Adding update patches from branch ovirt-3.3
- Declaring ovirt-3.3.2 patchsets scope in spec which declares all the merged
new patches

* Tue Nov 12 2013 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.13.0-11
- update from branch ovirt-3.3 which include:
  upgrade-fix-v3ResetMetaVolSize-argument
  lvm-Do-not-use-udev-cache-for-obtaining-device-list
  Fix-ballooning-rules-for-computing-the-minimum-avail
  Avoid-M2Crypto-races
  spec-declare-we-provide-an-existing-python-cpopen
  configuring-selinux-allowing-qemu-kvm-to-generate-co

* Tue Nov 12 2013 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.13.0-10
- Fix requires on post for hostname.

* Tue Nov 05 2013 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.13.0-9
- Build 4.13.0-9 from branch ovirt-3.3

* Wed Oct 30 2013 Cole Robinson <crobinso@redhat.com> - 4.12.1-5
- Fix broken hostname dep on rawhide

* Thu Oct 10 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.12.1-4
- remoteFileHandler: Add create exclusive option for truncateFile (BZ#979193)
- oop: improve safety for truncateFile

* Tue Oct 08 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.12.1-3
- vm.Vm._getUnderlyingDriveInfo: extract path of gluster disks (BZ#1007980)
- Require libvirt that allows vmUpdateDevice (BZ#1001001)
- imageSharing: return proper size in httpGetSize
- vdsmd.init: Add service-is-managed in shutdown_conflicting_srv (BZ#1006842)

* Tue Sep 10 2013 Federico Simoncelli <fsimonce@redhat.com> 4.12.1-2
- systemd init: no need to stop conflicting services (BZ#999664)

* Tue Aug 27 2013 Federico Simoncelli <fsimonce@redhat.com> 4.12.1-1
- update to 4.12.1

* Thu Aug 22 2013 Federico Simoncelli <fsimonce@redhat.com> 4.12.0-2
- Fix GlusterFS RPM dep to support GlusterFS SD (BZ#988299)

* Tue Aug 13 2013 Federico Simoncelli <fsimonce@redhat.com> 4.12.0-1
- update to 4.12.0 final release
- mom: Require latest mom
- Mark ksmtuned as conflicting service in the init file
- spec: vdsm-hook-sriov on el6 should not require
- Crash fix for migrations that involve devices with no aliases (BZ#988065)
- vdsm: Always retrieve alias for Balloon and Console (BZ#988065)
- vdsm: Fix regression introduced by refactoring (BZ#985735)
- VDSM now writes its version number in VDSM-generated
- Bump requires version of selinux-policy-targeted
- vdsm_reg: fix ovirt_node without default bridge (BZ#988990)
- Source Route script now checks that the DHCP response (BZ#994600)
- Management network is now kept in main routing table (BZ#984028)
- Only remove dhcp source routing if the removal reason (BZ#995142)
- image: use successor volume size when merging

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.12.0-0.2.rc3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 23 2013 Federico Simoncelli <fsimonce@redhat.com> 4.12.0-0.1.rc3
- update to vdsm-4.12.0-rc3

* Wed Jul 10 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.3-18
- vdsm.spec: update python-pthreading
- service: make iscsid a systemd dependency

* Tue Jun 4 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.3-17
- Makefile.am: ignore false positive pyflakes lvm.py
- Deactivate libvirtVM.Drives()
- vdsm: fix Vm cleanup routine
- Support teardownVolumePath(None)

* Tue Apr 23 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-16
- Don't user sudo in fuser
- svdsm: fix fuser import in supervdsmServer
- Removing vdsm configuration when removing vdsm service
- Seperating supervdsm log to supervdsm.log file
- vdsm.spec: Adding with_systemd macro
- spec: use the fedora systemd macros
- spec: enable gluster upstream and on fedora 19

* Tue Apr  9 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-15
- fix the patches backported to ovirt-3.2
- resync the fedora spec file with the upstream one

* Mon Apr  8 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-14
- fix storage.fuser
- Bump up libvirt version to fix network linking.

* Wed Apr 3 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.3-13
- Temporarily deactivate Gluster sub-package.

* Tue Mar 26 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.3-12
- Applying direct to spec the fence-agents changes and removing the patch.

* Mon Mar 25 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.3-11
- adapt vdsm.spec to new fence-agents package name.

* Thu Mar 14 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-10
- gluster: Handling Attribute error in Python 2.6
- bootstrap: remove glusterfs packages
- gluster: set glusterfs dependency version
- Do not delete the template when zeroing a dependant

* Wed Feb 27 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-9
- packaging: add load_needed_modules.py.in
- tool: _enable_bond_dev: reopen bonding_masters per bond

* Tue Feb 19 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-8
- configNet: allow delete/update of devices with no ifcfg (#906383)
- Requires policycoreutils-2.1.13-55 to avoid another
- After fail to connect to supervdsm more than 3 time

* Thu Feb 14 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-7
- Fedora 18: require a newer udev (applied properly to the fedora specfile)

* Wed Jan 30 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-6
- Explicitly shutdown  m2crypto socket
- spec: require policycoreutils and skip sebool errors
- spec: requires selinux-policy to avoid selinux failure
- vdsmd.service: require either ntpd or chronyd
- isRunning didn't check local variable before reading
- udev: Race fix- load and trigger dev rule (#891300)
- Change scsi_id command path to be configured at runtime (#886087)
- upgrade: force upgrade to v2 before upgrading to v3 (#893184)
- misc: rename safelease to clusterlock
- domain: select the cluster lock using makeClusterLock
- clusterlock: add the local locking implementation (#877715)
- upgrade: catch MetaDataKeyNotFoundError when preparing
- vdsm.spec: Require openssl (#905728)
- Fedora 18: require a newer udev
- fix sloppy backport of safelease rename
- removing the use of zombie reaper from supervdsm

* Fri Jan 18 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.3-5
- Searching for both py and pyc file to start super vdsm
- adding getHardwareInfo API to vdsm

* Tue Jan 15 2013 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.3-4
- python-ordereddict only for rhel more then 7
- dont require python ordereddict on fedora
- BuildRequires python-pthreading

* Wed Jan 02 2013 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-3
- caps.py: osversion() validate OVIRT
- restarting libvirtd didn't work over allinone setup
- Integrate Smartcard support

* Thu Dec 27 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-2
- api: Report CPU thread info in getVdsCapabilities
- schema: Missing comment for new VmDeviceType
- schema: Fix schema for VM.updateDevice

* Wed Dec 12 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.3-1
- vdsm-4.10.3

* Mon Nov 5 2012 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.1-100.gf2f6683
- vdsm-4.10.1-100-gf2f6683

* Wed Oct 31 2012 Douglas Schilling Landgraf <dougsland@redhat.com> 4.10.1-1
- vdsm-4.10.1
- merged vdsm.spec from f17 with last upstream vdsm.spec

* Wed Oct 24 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-12
- configure selinux for sanlock on nfs

* Sat Oct 20 2012 Peter Robinson <pbrobinson@fedoraproject.org> 4.10.0-11
- Merge F17 changes into F18+ and disable make check due to pep8 issues
- Add pyparted dependency

* Thu Oct  4 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-10
- BZ#845660 Use buffer size in multiplies of the recommended transfer size

* Mon Sep 24 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-9
- BZ#845660 Use the recommended alignment instead of using pagesize

* Tue Sep 11 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-8
- add the autotools support

* Fri Aug 17 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-7
- enable all the vdsm hooks

* Wed Aug  1 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-6
- BZ#842948: deployUtil - safely remove bridge

* Tue Jul 17 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-5
- configNet: atomicBackup: remove new files upon restore
- configNet: clear up atomicBackup arg
- Remove redundant 'explicitBonding' parameter from setupNetworks
- BZ#837054 - Do not detach network from the bond during bond resize
- BZ#836954 - Allow to break bond and create a new network on its interface in single action.
- BZ#837443: remove bridge before add VDSM bridge
- BZ#837443: removeVlan() drop/remove interface
- configNetwork: fix NetInfo call
- BZ#837443: replace the netinfo import
- BZ#837443: removeBridge() drop/remove interface
- ovirt_functions: fix elif statement
- BZ#838097 _addNetworkValidation: do not explode if STP/DNS1 option passed
- BZ#832199: move selinux from init to spec
- bump libvirt version to fix readonly lease unsupported issue

* Fri Jun 29 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-4
- deployUtil: use os.uname instead of /bin/uname
- deployUtil: slightly saner kernel version comparison
- BZ#835784 - Allow to create a network on top of existing bond in additional
  to create a new bond and network
- BZ#833119 - Allow to create VLANed network on top of existing bond
- BZ#833803 - Avoid bond breaking after network detach
- Handle bond properly if connectivity check fail.
- BZ#806555 having /etc/ovirt-node-* means it is a node

* Tue Jun 26 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-3
- BZ#832577: node can't be approved
- BZ#824298 fix typo in keyword argument exc_info

* Wed Jun 20 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-2
- deployUtil.yumFind: rename and simplify semantics
- drop deployUtil.yumSearch
- deployUtil.yumSearchVersion: compare versions sanely
- Iterates over delete candidates networks only once
- 'options' translation in setupNetworks is not relevant
- Minor optimization for delNetwork
- Don't ignore bridgeless networks in ifaceUsers
- Minor optimization for addNetwork
- Use already known iface in addNetwork
- Use proper MTU on bonding when add network
- Add bridge on top of VLAN if exists
- BZ#830485 - Add netConfigDirty bit to getVdsCaps report
- remove flag skipLibvirt
- BZ#826873 - Allow to change bond without network attached to it
- BZ#830486 - Allow to change network according the diffs from previous state
- BZ#826467 - Allow to remove bond and attach network to NIC
- Related to BZ#826873 - Allow to create bond without network

* Mon Jun 11 2012 Federico Simoncelli <fsimonce@redhat.com> 4.10.0-1
- vdsm-4.10.0

* Mon Jun  4 2012 Federico Simoncelli <fsimonce@redhat.com> 4.9.6-2.gite952471
- BZ#822158 Report version-release in a short format

* Mon Jun  4 2012 Federico Simoncelli <fsimonce@redhat.com> 4.9.6-1.gite952471
- vdsm-4.9.6-ge952471

* Mon May 28 2012 Federico Simoncelli <fsimonce@redhat.com> 4.9.6-0.git1b07249
- vdsm-4.9.6-g1b07249

* Tue Feb 28 2012 Dan Kenigsberg <danken@redhat.com> - 4.9.4-0.gb3642e5
- vdsm-4.9.4-0.gb3642e5

* Wed Jan 25 2012 Dan Kenigsberg <danken@redhat.com> - 4.9.3.2-0
- vdsm-4.9.3.2
- Reverts "BZ#773666 - Fix HSM flows should not change rw permissions."

* Mon Jan 16 2012 Federico Simoncelli <fsimonce@redhat.com> - 4.9.3.1-0
- vdsm-4.9.3.1

* Fri Jan 13 2012 Dan Kenigsberg <danken@redhat.com> - 4.9.2-1.git1d7b929
- vdsm-4.9.2-g1d7b929

* Tue Jan 10 2012 Federico Simoncelli <fsimonce@redhat.com> - 4.9.2-0.git951b41d
- vdsm-4.9.2-g951b41d

* Fri Dec 02 2011 Federico Simoncelli <fsimonce@redhat.com> - 4.9.1-2.git931a43e
- add the revision control comments to the specfile

* Wed Nov 30 2011 Federico Simoncelli <fsimonce@redhat.com> - 4.9.1-1.git6ee166c
- require iscsi-initiator-utils >= 6.2.0.872-14 bz442980
- fix the rpmlint errors

* Wed Oct 12 2011 Federico Simoncelli <fsimonce@redhat.com> - 4.9.0-0
- Initial upstream release

* Thu Nov 02 2006 Simon Grinberg <simong@qumranet.com> -  0.0-1
- Initial build
